@@ -4,15 +4,16 @@ import json
 from pathlib import Path
 
 import elasticsearch
-from elasticsearch_dsl import Search
-from retry import retry
+from elasticsearch import Elasticsearch, AsyncElasticsearch
+from elasticsearch.helpers import bulk
+from tenacity import retry, stop_after_attempt, wait_fixed
 
 from .errors import (
     ElasticsearchUnreachableError,
     ElasticsearchNotReadyError,
 )
 from .logger import get_logger
-from .utils import recurse_splat_key
+from .utils import batch, recurse_splat_key
 
 
 def check_elasticsearch(
@@ -38,13 +39,13 @@ def check_elasticsearch(
         ) from e
 
 
-@retry(tries=3, backoff=5, delay=2)
+@retry(stop=stop_after_attempt(5), wait=wait_fixed(0.5))
 def document_exists(
     elasticsearch_client: Elasticsearch,
     doc: Dict[str, Any],
     index: str,
     identity_fields: List[str],
-    overwrite: bool = False,
+    delete_if_exists: bool = False,
 ) -> bool:
 
     log = get_logger("elasticbud.document_exists")
@@ -70,7 +71,7 @@ def document_exists(
 
     hits = resp["hits"]["hits"]
     if len(hits) > 0:
-        if overwrite:
+        if delete_if_exists:
             if len(hits) > 1:
                 log.warning(f"{len(hits)} {index} documents matched the query: {body}")
             for hit in hits:
@@ -107,7 +108,11 @@ def doc_gen(
             doc
         )  # convert Index classes to plain dictionaries for Elasticsearch API
         if identity_fields is not None and document_exists(
-            elasticsearch_client, doc, index, identity_fields, overwrite
+            elasticsearch_client,
+            doc,
+            index,
+            identity_fields,
+            delete_if_exists=overwrite,
         ):
             exists += 1
             continue
@@ -121,26 +126,7 @@ def doc_gen(
         )
 
 
-def fields_in_hits(hits: Iterator[Dict[str, Any]]) -> List[str]:
-    """
-    List all unique field names present in a set of hits
-    """
-
-    fields = set()
-    for hit in hits:
-        for field in hit["_source"].keys():
-            fields.add(field)
-
-    return list(fields)
-
-
-def batch(iterable: Iterable, n: int = 1) -> Generator[Iterable, None, None]:
-    l = len(iterable)
-    for ndx in range(0, l, n):
-        yield iterable[ndx : min(ndx + n, l)]
-
-
-@retry(tries=3, backoff=5, delay=2)
+@retry(stop=stop_after_attempt(5), wait=wait_fixed(0.5))
 def index_to_elasticsearch(
     elasticsearch_client: Elasticsearch,
     index: str,
@@ -170,7 +156,7 @@ def index_to_elasticsearch(
         log.info(f"applied index template named '{index}' from {template_source}")
 
     if batch_size is None:
-        elasticsearch.helpers.bulk(
+        bulk(
             elasticsearch_client,
             doc_gen(
                 elasticsearch_client, docs, index, identity_fields, overwrite, quiet
@@ -178,7 +164,7 @@ def index_to_elasticsearch(
         )
     else:
         for docs_batch in batch(docs, n=batch_size):
-            elasticsearch.helpers.bulk(
+            bulk(
                 elasticsearch_client,
                 doc_gen(
                     elasticsearch_client,
@@ -193,7 +179,7 @@ def index_to_elasticsearch(
         log.debug("bulk indexing complete")
 
 
-@retry(tries=3, backoff=5, delay=2)
+@retry(stop=stop_after_attempt(5), wait=wait_fixed(0.5))
 def get_response_value(
     elasticsearch_client: Elasticsearch,
     index: str,
@@ -254,3 +240,16 @@ def get_response_value(
             log.info(
                 f"query returned {len(values) if values is not None else 0} values"
             )
+
+
+def fields_in_hits(hits: Iterator[Dict[str, Any]]) -> List[str]:
+    """
+    List all unique field names present in a set of hits
+    """
+
+    fields = set()
+    for hit in hits:
+        for field in hit["_source"].keys():
+            fields.add(field)
+
+    return list(fields)
